==> react-bootstrap-0.2.0.tgz: package/es/components/CardWithTabs/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Children, cloneElement } from 'react';

import Card from '../Card';
import Tabs from '../Tabs';

var CardWithTabs = (_temp2 = _class = function (_Component) {
  _inherits(CardWithTabs, _Component);

  function CardWithTabs() {
    var _temp, _this, _ret;

    _classCallCheck(this, CardWithTabs);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      selectedIndex: _this.props.defaultIndex
    }, _this.onToggle = function (selectedIndex) {
      return _this.setState({
        selectedIndex: selectedIndex
      }, function () {
        return _this.props.onToggle(selectedIndex);
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  CardWithTabs.prototype.render = function render() {
    var _this2 = this;

    var children = this.props.children;
    var selectedIndex = this.state.selectedIndex;


    return React.createElement(
      Card.Container,
      null,
      React.createElement(
        Card.Header,
        null,
        React.createElement(
          Tabs.Nav,
          { className: 'card-header-tabs' },
          Children.map(children, function (_ref, index) {
            var title = _ref.props.title;
            return React.createElement(Tabs.NavItem, {
              key: index,
              title: title,
              active: selectedIndex === index,
              onClick: function onClick() {
                return _this2.onToggle(index);
              }
            });
          })
        )
      ),
      React.createElement(
        Card.Body,
        null,
        Children.map(children, function (item, index) {
          return cloneElement(item, { key: index, active: selectedIndex === index });
        })
      )
    );
  };

  return CardWithTabs;
}(Component), _class.defaultProps = _extends({}, Tabs.defaultProps), _class.Item = Tabs.Item, _temp2);
CardWithTabs.propTypes = process.env.NODE_ENV !== "production" ? _extends({}, Tabs.propTypes) : {};


export default CardWithTabs;

==> react-bootstrap-0.4.0.tgz: package/es/components/CardWithTabs/index.js <==
var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Children, cloneElement } from 'react';
import PropTypes from 'prop-types';

import Card from '../Card';
import Tabs from '../Tabs';

var CardWithTabs = (_temp2 = _class = function (_Component) {
  _inherits(CardWithTabs, _Component);

  function CardWithTabs() {
    var _temp, _this, _ret;

    _classCallCheck(this, CardWithTabs);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      selectedIndex: _this.props.defaultIndex
    }, _this.onToggle = function (selectedIndex) {
      return _this.setState({
        selectedIndex: selectedIndex
      }, function () {
        return _this.props.onToggle(selectedIndex);
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  CardWithTabs.prototype.render = function render() {
    var _this2 = this;

    var children = this.props.children;
    var selectedIndex = this.state.selectedIndex;


    return React.createElement(
      Card.Container,
      null,
      React.createElement(
        Card.Header,
        null,
        React.createElement(
          Tabs.Nav,
          { className: 'card-header-tabs' },
          Children.map(children, function (_ref, index) {
            var title = _ref.props.title;
            return React.createElement(Tabs.NavItem, {
              key: index,
              title: title,
              active: selectedIndex === index,
              onClick: function onClick() {
                return _this2.onToggle(index);
              }
            });
          })
        )
      ),
      React.createElement(
        Card.Body,
        null,
        Children.map(children, function (item, index) {
          return cloneElement(item, { key: index, active: selectedIndex === index });
        })
      )
    );
  };

  return CardWithTabs;
}(Component), _class.defaultProps = {
  defaultIndex: 0,
  onToggle: function onToggle() {},
  children: null
}, _class.Item = Tabs.Item, _temp2);
CardWithTabs.propTypes = process.env.NODE_ENV !== "production" ? {
  defaultIndex: PropTypes.number,
  onToggle: PropTypes.func,
  children: PropTypes.node
} : {};


export default CardWithTabs;
